'use strict';

var __getOwnPropNames = Object.getOwnPropertyNames;
var __esm = (fn, res) => function __init() {
  return fn && (res = (0, fn[__getOwnPropNames(fn)[0]])(fn = 0)), res;
};
var __commonJS = (cb, mod) => function __require() {
  return mod || (0, cb[__getOwnPropNames(cb)[0]])((mod = { exports: {} }).exports, mod), mod.exports;
};

// lib/config/recommended.ts
var require_recommended = __commonJS({
  "lib/config/recommended.ts"(exports, module) {
    var config = {
      plugins: ["@orbit-ui"],
      extends: [
        "plugin:@orbit-ui/jsx-a11y"
      ]
    };
    module.exports = config;
  }
});

// lib/utils/patterns.ts
var sourceFiles;
var init_patterns = __esm({
  "lib/utils/patterns.ts"() {
    sourceFiles = [
      "*.[jt]s?(x)",
      "*.[cm]js"
    ];
  }
});

// lib/config/jsx-a11y.ts
var require_jsx_a11y = __commonJS({
  "lib/config/jsx-a11y.ts"(exports, module) {
    init_patterns();
    var config = {
      overrides: [
        {
          files: sourceFiles,
          plugins: ["jsx-a11y"],
          parserOptions: {
            ecmaFeatures: {
              jsx: true
            }
          },
          rules: {
            // This rule ensures that all labels have an associated control that they are labeling.
            // However, this rule causes a lot of false positive, since our current implementation of our company's design system
            // does not use the "for" attribute in the label element and automatically add it inside Fields.
            // Therefore, we are disabling this rule.
            "jsx-a11y/label-has-associated-control:": "off"
          },
          settings: {
            "jsx-a11y": {
              components: {
                // HTML Components Wrappers
                "A": "a",
                "Address": "address",
                "Article": "article",
                "HtmlButton": "button",
                "Div": "div",
                "HtmlFooter": "footer",
                "HtmlForm": "form",
                "HtmlH1": "h1",
                "HtmlH2": "h2",
                "HtmlH3": "h3",
                "HtmlH4": "h4",
                "HtmlH5": "h5",
                "HtmlH6": "h6",
                "HtmlHeader": "header",
                "Img": "img",
                "HtmlInput": "input",
                "HtmlLabel": "label",
                "LI": "li",
                "Main": "main",
                "Nav": "nav",
                "OL": "ol",
                "HtmlParagraph": "p",
                "HtmlSection": "section",
                "Span": "span",
                "Table": "table",
                "TBody": "tbody",
                "TD": "td",
                "HtmlTextArea": "textarea",
                "TFoot": "tfoot",
                "TH": "th",
                "THead": "thead",
                "TR": "tr",
                "UL": "ul",
                // Orbit components that are simple HTML element wrappers and behave like html elements
                Label: "label",
                Link: "a",
                TextLink: "a",
                IconLink: "a",
                TileLink: "a",
                Paragraph: "p",
                Text: "span",
                // Orbit components that are basically Divs synthax shortcuts and behave like html elements
                Flex: "div",
                Grid: "div",
                Inline: "div",
                Stack: "div",
                ThemeProvider: "div",
                Divider: "div",
                Transition: "div"
              }
            }
          }
        }
      ]
    };
    module.exports = config;
  }
});

// lib/index.ts
var require_lib = __commonJS({
  "lib/index.ts"(exports, module) {
    var plugin = {
      configs: {
        // Parts
        recommended: require_recommended(),
        "jsx-a11y": require_jsx_a11y()
      }
    };
    module.exports = plugin;
  }
});
var index = require_lib();

module.exports = index;
